@@ -15,11 +15,11 @@ Passwd::Keyring::Gnome - Password storage implementation based on GNOME Keyring.
 
 =head1 VERSION
 
-Version 0.25
+Version 0.2501
 
 =cut
 
-our $VERSION = '0.25';
+our $VERSION = '0.2501';
 
 bootstrap Passwd::Keyring::Gnome $VERSION;
 
@@ -40,7 +40,7 @@ Gnome Keyring based implementation of L<Keyring>.
     # plus
     $keyring->clear_password("John", "my-pseudodomain");
 
-Note: see L<Passwd::Keyring::KeyringAPI> for detailed comments on
+Note: see L<Passwd::Keyring::Auto::KeyringAPI> for detailed comments on
 keyring method semantics (this document is installed with
 Passwd::Keyring::Auto package).
 
@@ -131,7 +131,7 @@ sub is_persistent {
 
 =head1 AUTHOR
 
-Marcin Kasperski, C<< <Marcin.Kasperski at mekk.waw.pl> >>
+Marcin Kasperski
 
 =head1 BUGS
 
@@ -146,7 +146,11 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-    L<https://bitbucket.org/Mekk/perl-keyring-gnome>
+L<http://search.cpan.org/~mekk/Passwd-Keyring-Gnome/>
+
+Source code is tracked at:
+
+L<https://bitbucket.org/Mekk/perl-keyring-gnome>
 
 =head1 LICENSE AND COPYRIGHT
 
